"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class ServiceLevelSwyftEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | same_day | Next Day|
    | next_day | Next Day|
    """
    SAME_DAY = 'same_day'
    NEXT_DAY = 'next_day'

class ServiceLevelVehoEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | veho_next_day | Veho Next Day |
    """
    VEHO_NEXT_DAY = 'veho_next_day'

class ServiceLevelUDSEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | uds_next_day | Next Day|
    """
    UDS_NEXT_DAY = 'uds_next_day'

class ServiceLevelEvriUKEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | hermes_uk_courier_service | Courier Collection|
    | hermes_uk_parcelshop_dropoff | ParcelShop Drop-Off|
    | hermes_uk_parcelshop_dropoff_nextday | ParcelShop Drop-Off Next Day|
    | hermes_uk_postable | Postable|
    | hermes_uk_postable_nextday | Postable Next Day|
    """
    HERMES_UK_COURIER_SERVICE = 'hermes_uk_courier_service'
    HERMES_UK_PARCELSHOP_DROPOFF = 'hermes_uk_parcelshop_dropoff'
    HERMES_UK_PARCELSHOP_DROPOFF_NEXTDAY = 'hermes_uk_parcelshop_dropoff_nextday'
    HERMES_UK_POSTABLE = 'hermes_uk_postable'
    HERMES_UK_POSTABLE_NEXTDAY = 'hermes_uk_postable_nextday'

class ServiceLevelLasershipEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | lasership_routed_delivery | Routed Delivery|
    """
    LASERSHIP_ROUTED_DELIVERY = 'lasership_routed_delivery'

class ServiceLevelOnTracEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | ontrac_ground | Ground|
    | ontrac_sunrise_gold | Sunrise Gold|
    | ontrac_sunrise | Sunrise|
    """
    ONTRAC_GROUND = 'ontrac_ground'
    ONTRAC_SUNRISE_GOLD = 'ontrac_sunrise_gold'
    ONTRAC_SUNRISE = 'ontrac_sunrise'

class ServiceLevelSendleEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | sendle_parcel | Sendle Parcel|
    """
    SENDLE_PARCEL = 'sendle_parcel'

class ServiceLevelRoyalMailEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | royal_mail_tracked_letter_boxable_24_no_signature | Royal Mail Tracked Letter-Boxable 24 No Signature|
    | royal_mail_tracked_letter_boxable_48_no_signature | Royal Mail Tracked Letter-Boxable 48 No Signature|
    | royal_mail_tracked_24_returns | Royal Mail Tracked Returns 24|
    | royal_mail_tracked_48_returns | Royal Mail Tracked Returns 48|
    | royal_mail_special_delivery_guaranteed_1pm | Special Delivery Guaranteed by 1pm
    | royal_mail_special_delivery_guaranteed_9am | Special Delivery Guaranteed by 9am
    | royal_mail_24 | RoyalMail 24
    | royal_mail_48 | RoyalMail 48
    | royal_mail_signed_for_first_class | Signed for First Class
    | royal_mail_signed_for_second_class | Signed for Second Class
    | royal_mail_standard_first_class | Standard First Class
    | royal_mail_standard_second_class | Standard Second Class
    | royal_mail_tracked_24_no_signature | Royal Mail Tracked 24 No Signature
    | royal_mail_tracked_48_no_signature | Royal Mail Ttacked 48 No Signature
    | royal_mail_intl_bus_mail_lrg_ltr_zone_sort_pri | International Business Mail Large Letter Zone Sort Priority
    | royal_mail_intl_bus_parcels_tracked_zone_sort | International Business Parcels Tracked Zone Sort
    | royal_mail_intl_bus_parcels_tracked_country_priced | International Business Parcels Tracked Country Priced
    | royal_mail_intl_bus_parcels_tracked_signed_zone_srt | International Business Parcels & Signed Zone Sort
    | royal_mail_24_flat_rate | Royal Mail 24 Parcel Flat Rate
    | royal_mail_48_flat_rate | Royal Mail 48 Parcel Flat Rate
    """
    ROYAL_MAIL_TRACKED_LETTER_BOXABLE_24_NO_SIGNATURE = 'royal_mail_tracked_letter_boxable_24_no_signature'
    ROYAL_MAIL_TRACKED_LETTER_BOXABLE_48_NO_SIGNATURE = 'royal_mail_tracked_letter_boxable_48_no_signature'
    ROYAL_MAIL_TRACKED_24_RETURNS = 'royal_mail_tracked_24_returns'
    ROYAL_MAIL_TRACKED_48_RETURNS = 'royal_mail_tracked_48_returns'
    ROYAL_MAIL_SPECIAL_DELIVERY_GUARANTEED_1PM = 'royal_mail_special_delivery_guaranteed_1pm'
    ROYAL_MAIL_SPECIAL_DELIVERY_GUARANTEED_9AM = 'royal_mail_special_delivery_guaranteed_9am'
    ROYAL_MAIL_24 = 'royal_mail_24'
    ROYAL_MAIL_48 = 'royal_mail_48'
    ROYAL_MAIL_SIGNED_FOR_FIRST_CLASS = 'royal_mail_signed_for_first_class'
    ROYAL_MAIL_SIGNED_FOR_SECOND_CLASS = 'royal_mail_signed_for_second_class'
    ROYAL_MAIL_STANDARD_FIRST_CLASS = 'royal_mail_standard_first_class'
    ROYAL_MAIL_STANDARD_SECOND_CLASS = 'royal_mail_standard_second_class'
    ROYAL_MAIL_TRACKED_24_NO_SIGNATURE = 'royal_mail_tracked_24_no_signature'
    ROYAL_MAIL_TRACKED_48_NO_SIGNATURE = 'royal_mail_tracked_48_no_signature'
    ROYAL_MAIL_INTL_BUS_MAIL_LRG_LTR_ZONE_SORT_PRI = 'royal_mail_intl_bus_mail_lrg_ltr_zone_sort_pri'
    ROYAL_MAIL_INTL_BUS_PARCELS_TRACKED_ZONE_SORT = 'royal_mail_intl_bus_parcels_tracked_zone_sort'
    ROYAL_MAIL_INTL_BUS_PARCELS_TRACKED_COUNTRY_PRICED = 'royal_mail_intl_bus_parcels_tracked_country_priced'
    ROYAL_MAIL_INTL_BUS_PARCELS_TRACKED_SIGNED_ZONE_SRT = 'royal_mail_intl_bus_parcels_tracked_signed_zone_srt'
    ROYAL_MAIL_24_FLAT_RATE = 'royal_mail_24_flat_rate'
    ROYAL_MAIL_48_FLAT_RATE = 'royal_mail_48_flat_rate'

class ServiceLevelePostGlobalEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | rr_donnelley_domestic_economy_parcel | Domestic Economy Parcel|
    | rr_donnelley_domestic_priority_parcel | Domestic Priority Parcel |
    | rr_donnelley_domestic_parcel_bpm | Domestic Parcel BPM|
    | rr_donnelley_priority_domestic_priority_parcel_bpm | Domestic Priority Parcel BPM|
    | rr_donnelley_priority_parcel_delcon | International Priority Parcel DelCon|
    | rr_donnelley_priority_parcel_nondelcon | International Priority Parcel NonDelcon|
    | rr_donnelley_economy_parcel | Economy Parcel Service |
    | rr_donnelley_ipa | International Priority Airmail (IPA)|
    | rr_donnelley_courier | International Courier|
    | rr_donnelley_isal | International Surface Air Lift (ISAL)|
    | rr_donnelley_epacket | e-Packet|
    | rr_donnelley_pmi | Priority Mail International|
    | rr_donnelley_emi | Express Mail International|
    """
    RR_DONNELLEY_DOMESTIC_ECONOMY_PARCEL = 'rr_donnelley_domestic_economy_parcel'
    RR_DONNELLEY_DOMESTIC_PRIORITY_PARCEL = 'rr_donnelley_domestic_priority_parcel'
    RR_DONNELLEY_DOMESTIC_PARCEL_BPM = 'rr_donnelley_domestic_parcel_bpm'
    RR_DONNELLEY_PRIORITY_DOMESTIC_PRIORITY_PARCEL_BPM = 'rr_donnelley_priority_domestic_priority_parcel_bpm'
    RR_DONNELLEY_PRIORITY_PARCEL_DELCON = 'rr_donnelley_priority_parcel_delcon'
    RR_DONNELLEY_PRIORITY_PARCEL_NONDELCON = 'rr_donnelley_priority_parcel_nondelcon'
    RR_DONNELLEY_ECONOMY_PARCEL = 'rr_donnelley_economy_parcel'
    RR_DONNELLEY_IPA = 'rr_donnelley_ipa'
    RR_DONNELLEY_COURIER = 'rr_donnelley_courier'
    RR_DONNELLEY_ISAL = 'rr_donnelley_isal'
    RR_DONNELLEY_EPACKET = 'rr_donnelley_epacket'
    RR_DONNELLEY_PMI = 'rr_donnelley_pmi'
    RR_DONNELLEY_EMI = 'rr_donnelley_emi'

class ServiceLevelPostItalianeEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | poste_italiane_delivery_business_express | Poste Delivery Business Express|
    """
    POSTE_ITALIANE_DELIVERY_BUSINESS_EXPRESS = 'poste_italiane_delivery_business_express'

class ServiceLevelParcelforceEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | parcelforce_express48 | Express 48|
    | parcelforce_express24 | Express 24|
    | parcelforce_expressam | Express AM|
    """
    PARCELFORCE_EXPRESS48 = 'parcelforce_express48'
    PARCELFORCE_EXPRESS24 = 'parcelforce_express24'
    PARCELFORCE_EXPRESSAM = 'parcelforce_expressam'

class ServiceLevelMaergoEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | x_delivery_expedited | Expedited|
    """
    X_DELIVERY_EXPEDITED = 'x_delivery_expedited'

class ServiceLevelMondialRelayEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | mondial_relay_pointrelais | Point Relais|
    """
    MONDIAL_RELAY_POINTRELAIS = 'mondial_relay_pointrelais'

class ServiceLevelLSOEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | lso_ground | Ground|
    | lso_economy_next_day | Economy Next Day|
    | lso_saturday_delivery | Saturday Delivery|
    | lso_2nd_day | 2nd Day|
    | lso_priority_next_day | Priority Next Day|
    | lso_early_overnight | Early Overnight|
    """
    LSO_GROUND = 'lso_ground'
    LSO_ECONOMY_NEXT_DAY = 'lso_economy_next_day'
    LSO_SATURDAY_DELIVERY = 'lso_saturday_delivery'
    LSO_2ND_DAY = 'lso_2nd_day'
    LSO_PRIORITY_NEXT_DAY = 'lso_priority_next_day'
    LSO_EARLY_OVERNIGHT = 'lso_early_overnight'

class ServiceLevelGLSUSEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | gls_us_cps | GSO Ground|
    | gls_us_eps | Early Priority Overnight|
    | gls_us_ess | Early Saturday Delivery|
    | gls_us_nps | Noon Priority Overnight|
    | gls_us_pds | Priority Overnight|
    | gls_us_sds | Saturday Delivery|
    """
    GLS_US_CPS = 'gls_us_cps'
    GLS_US_EPS = 'gls_us_eps'
    GLS_US_ESS = 'gls_us_ess'
    GLS_US_NPS = 'gls_us_nps'
    GLS_US_PDS = 'gls_us_pds'
    GLS_US_SDS = 'gls_us_sds'

class ServiceLevelGlobegisticsEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | globegistics_priority_mail_express_international | Globegistics Priority Mail Express International|
    | globegistics_priority_mail_international | Globegistics Priority Mail International|
    | globegistics_priority_mail_express_international_pds | Globegistics Priority Mail Express International PreSort Drop Ship|
    | globegistics_priority_mail_international_pds | Globegistics Priority Mail International PreSort Drop Ship|
    | globegistics_epacket | Globegistics ePacket|
    | globegistics_ecom_tracked_ddp | Globegistics eCom Tracked DDP|
    | globegistics_ecom_packet_ddp | Globegistics eCom Packet DDP|
    | globegistics_ecom_priority_mail_international_ddp | Globegistics eCom Priority Mail International DDP|
    | globegistics_ecom_priority_mail_express_international_ddp | Globegistics eCom Priority Mail Express International DDP|
    | globegistics_ecom_extra | Globegistics eCom Extra|
    | globegistics_ecom_international_priority_airmail | Globegistics eCom International Priority Airmail|
    | globegistics_ecom_international_surface_airlift | Globegistics eCom International Surface Air Lift|
    """
    GLOBEGISTICS_PRIORITY_MAIL_EXPRESS_INTERNATIONAL = 'globegistics_priority_mail_express_international'
    GLOBEGISTICS_PRIORITY_MAIL_INTERNATIONAL = 'globegistics_priority_mail_international'
    GLOBEGISTICS_PRIORITY_MAIL_EXPRESS_INTERNATIONAL_PDS = 'globegistics_priority_mail_express_international_pds'
    GLOBEGISTICS_PRIORITY_MAIL_INTERNATIONAL_PDS = 'globegistics_priority_mail_international_pds'
    GLOBEGISTICS_EPACKET = 'globegistics_epacket'
    GLOBEGISTICS_ECOM_TRACKED_DDP = 'globegistics_ecom_tracked_ddp'
    GLOBEGISTICS_ECOM_PACKET_DDP = 'globegistics_ecom_packet_ddp'
    GLOBEGISTICS_ECOM_PRIORITY_MAIL_INTERNATIONAL_DDP = 'globegistics_ecom_priority_mail_international_ddp'
    GLOBEGISTICS_ECOM_PRIORITY_MAIL_EXPRESS_INTERNATIONAL_DDP = 'globegistics_ecom_priority_mail_express_international_ddp'
    GLOBEGISTICS_ECOM_EXTRA = 'globegistics_ecom_extra'
    GLOBEGISTICS_ECOM_INTERNATIONAL_PRIORITY_AIRMAIL = 'globegistics_ecom_international_priority_airmail'
    GLOBEGISTICS_ECOM_INTERNATIONAL_SURFACE_AIRLIFT = 'globegistics_ecom_international_surface_airlift'

class ServiceLevelAramexAustraliaEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | fastway_australia_parcel | Parcel|
    | fastway_australia_satchel | Satchel|
    | fastway_australia_box_small | Box Small|
    | fastway_australia_box_medium | Box Medium|
    | fastway_australia_box_large | Box Large|
    """
    FASTWAY_AUSTRALIA_PARCEL = 'fastway_australia_parcel'
    FASTWAY_AUSTRALIA_SATCHEL = 'fastway_australia_satchel'
    FASTWAY_AUSTRALIA_BOX_SMALL = 'fastway_australia_box_small'
    FASTWAY_AUSTRALIA_BOX_MEDIUM = 'fastway_australia_box_medium'
    FASTWAY_AUSTRALIA_BOX_LARGE = 'fastway_australia_box_large'

class ServiceLevelDeutschePostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | deutsche_post_postkarte | Postkarte|
    | deutsche_post_standardbrief | Standardbrief|
    | deutsche_post_kompaktbrief | Kompaktbrief|
    | deutsche_post_grossbrief | Grossbrief|
    | deutsche_post_maxibrief | Maxibrief|
    | deutsche_post_maxibrief_plus | Maxibrief Plus|
    | deutsche_post_warenpost_international_xs | Warenpost International XS|
    | deutsche_post_warenpost_international_s | Warenpost International S|
    | deutsche_post_warenpost_international_m | Warenpost International M|
    | deutsche_post_warenpost_international_l | Warenpost International L|
    """
    DEUTSCHE_POST_POSTKARTE = 'deutsche_post_postkarte'
    DEUTSCHE_POST_STANDARDBRIEF = 'deutsche_post_standardbrief'
    DEUTSCHE_POST_KOMPAKTBRIEF = 'deutsche_post_kompaktbrief'
    DEUTSCHE_POST_GROSSBRIEF = 'deutsche_post_grossbrief'
    DEUTSCHE_POST_MAXIBRIEF = 'deutsche_post_maxibrief'
    DEUTSCHE_POST_MAXIBRIEF_PLUS = 'deutsche_post_maxibrief_plus'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_XS = 'deutsche_post_warenpost_international_xs'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_S = 'deutsche_post_warenpost_international_s'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_M = 'deutsche_post_warenpost_international_m'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_L = 'deutsche_post_warenpost_international_l'

class ServiceLevelDPDUKEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dpd_uk_ship_to_shop | Ship to shop|
    | dpd_uk_1030 | Door to door 10.30 next day|
    | dpd_uk_1200 | Door to door 12.00 next day|
    | dpd_uk_saturday | Saturday Delivery|
    | dpd_uk_saturday_1030 | Saturday Delivery 10.30|
    | dpd_uk_saturday_1200 | Saturday Delivery 12.00|
    | dpd_uk_sunday | Sunday Delivery|
    | dpd_uk_sunday_1030 | Sunday Delivery 10.30|
    | dpd_uk_sunday_1200 | Sunday Delivery 12.00|
    | dpd_uk_next_day | Next day|
    | dpd_uk_two_day | Two day|
    | dpd_uk_classic | DPD Classic|
    | dpd_uk_air_classic | DPD Air Classic|
    | dpd_uk_air_express | DPD Air Express|
    | dpd_uk_direct | DPD Direct|
    | dpd_uk_direct_tracked_mail| DPD Tracked Mail|
    | dpd_uk_pickup_returns | Pickup Returns|
    """
    DPD_UK_SHIP_TO_SHOP = 'dpd_uk_ship_to_shop'
    DPD_UK_1030 = 'dpd_uk_1030'
    DPD_UK_1200 = 'dpd_uk_1200'
    DPD_UK_SATURDAY = 'dpd_uk_saturday'
    DPD_UK_SATURDAY_1030 = 'dpd_uk_saturday_1030'
    DPD_UK_SATURDAY_1200 = 'dpd_uk_saturday_1200'
    DPD_UK_SUNDAY = 'dpd_uk_sunday'
    DPD_UK_SUNDAY_1030 = 'dpd_uk_sunday_1030'
    DPD_UK_SUNDAY_1200 = 'dpd_uk_sunday_1200'
    DPD_UK_NEXT_DAY = 'dpd_uk_next_day'
    DPD_UK_TWO_DAY = 'dpd_uk_two_day'
    DPD_UK_CLASSIC = 'dpd_uk_classic'
    DPD_UK_AIR_CLASSIC = 'dpd_uk_air_classic'
    DPD_UK_AIR_EXPRESS = 'dpd_uk_air_express'
    DPD_UK_DIRECT = 'dpd_uk_direct'
    DPD_UK_DIRECT_TRACKED_MAIL = 'dpd_uk_direct_tracked_mail'
    DPD_UK_PICKUP_RETURNS = 'dpd_uk_pickup_returns'

class ServiceLevelDPDDEEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dpd_de_classic | DPD Classic|
    """
    DPD_DE_CLASSIC = 'dpd_de_classic'

class ServiceLevelDHLGermanyEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dhl_germany_europaket | DHL Germany Europaket|
    | dhl_germany_paket | DHL Germany Paket|
    | dhl_germany_paket_connect | DHL Germany Paket Connect|
    | dhl_germany_paket_international | DHL Germany Paket International|
    | dhl_germany_paket_priority | DHL Germany Paket Priority|
    | dhl_germany_paket_sameday | DHL Germany Paket Sameday|
    """
    DHL_GERMANY_EUROPAKET = 'dhl_germany_europaket'
    DHL_GERMANY_PAKET = 'dhl_germany_paket'
    DHL_GERMANY_PAKET_CONNECT = 'dhl_germany_paket_connect'
    DHL_GERMANY_PAKET_INTERNATIONAL = 'dhl_germany_paket_international'
    DHL_GERMANY_PAKET_PRIORITY = 'dhl_germany_paket_priority'
    DHL_GERMANY_PAKET_SAMEDAY = 'dhl_germany_paket_sameday'

class ServiceLevelDHLeCommerceEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dhl_ecommerce_marketing_parcel_expedited | Marketing Parcel Expedited|
    | dhl_ecommerce_globalmail_business_ipa | GlobalMail Business IPA|
    | dhl_ecommerce_parcel_international_direct | Parcel International Direct|
    | dhl_ecommerce_parcels_expedited_max | Parcels Expedited Max|
    | dhl_ecommerce_bpm_ground | Bounded Printed Matter Ground|
    | dhl_ecommerce_priority_expedited | Priority Expedited|
    | dhl_ecommerce_globalmail_packet_ipa | GlobalMail Packet IPA|
    | dhl_ecommerce_globalmail_packet_isal | GlobalMail Packet ISAL|
    | dhl_ecommerce_easy_return_plus | Easy Return Plus|
    | dhl_ecommerce_marketing_parcel_ground | Marketing Parcel Ground|
    | dhl_ecommerce_first_class_parcel_expedited | First Class Parcel Expedited|
    | dhl_ecommerce_globalmail_business_priority | GlobalMail Business Priority|
    | dhl_ecommerce_parcels_expedited | Parcels Expedited|
    | dhl_ecommerce_globalmail_business_isal | GlobalMail Business ISAL|
    | dhl_ecommerce_parcel_plus_expedited_max | Parcel Plus Expedited Max|
    | dhl_ecommerce_globalmail_packet_plus | GlobalMail Packet Plus|
    | dhl_ecommerce_parcels_ground | Parcels Ground|
    | dhl_ecommerce_expedited | Expedited|
    | dhl_ecommerce_parcel_plus_ground | Parcel Plus Ground|
    | dhl_ecommerce_parcel_international_standard | Parcel International Standard|
    | dhl_ecommerce_bpm_expedited | Bounded Printed Matter Expedited|
    | dhl_ecommerce_parcel_international_expedited | Parcel International Expedited|
    | dhl_ecommerce_globalmail_packet_priority | GlobalMail Packet Priority|
    | dhl_ecommerce_easy_return_light | Easy Return Light|
    | dhl_ecommerce_parcel_plus_expedited | Parcel Plus Expedited|
    | dhl_ecommerce_globalmail_business_standard | GlobalMail Packet Standard|
    | dhl_ecommerce_ground | Ground|
    | dhl_ecommerce_globalmail_packet_standard | GlobalMail Business Standard|
    """
    DHL_ECOMMERCE_MARKETING_PARCEL_EXPEDITED = 'dhl_ecommerce_marketing_parcel_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_IPA = 'dhl_ecommerce_globalmail_business_ipa'
    DHL_ECOMMERCE_PARCEL_INTERNATIONAL_DIRECT = 'dhl_ecommerce_parcel_international_direct'
    DHL_ECOMMERCE_PARCELS_EXPEDITED_MAX = 'dhl_ecommerce_parcels_expedited_max'
    DHL_ECOMMERCE_BPM_GROUND = 'dhl_ecommerce_bpm_ground'
    DHL_ECOMMERCE_PRIORITY_EXPEDITED = 'dhl_ecommerce_priority_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_IPA = 'dhl_ecommerce_globalmail_packet_ipa'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_ISAL = 'dhl_ecommerce_globalmail_packet_isal'
    DHL_ECOMMERCE_EASY_RETURN_PLUS = 'dhl_ecommerce_easy_return_plus'
    DHL_ECOMMERCE_MARKETING_PARCEL_GROUND = 'dhl_ecommerce_marketing_parcel_ground'
    DHL_ECOMMERCE_FIRST_CLASS_PARCEL_EXPEDITED = 'dhl_ecommerce_first_class_parcel_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_PRIORITY = 'dhl_ecommerce_globalmail_business_priority'
    DHL_ECOMMERCE_PARCELS_EXPEDITED = 'dhl_ecommerce_parcels_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_ISAL = 'dhl_ecommerce_globalmail_business_isal'
    DHL_ECOMMERCE_PARCEL_PLUS_EXPEDITED_MAX = 'dhl_ecommerce_parcel_plus_expedited_max'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_PLUS = 'dhl_ecommerce_globalmail_packet_plus'
    DHL_ECOMMERCE_PARCELS_GROUND = 'dhl_ecommerce_parcels_ground'
    DHL_ECOMMERCE_EXPEDITED = 'dhl_ecommerce_expedited'
    DHL_ECOMMERCE_PARCEL_PLUS_GROUND = 'dhl_ecommerce_parcel_plus_ground'
    DHL_ECOMMERCE_PARCEL_INTERNATIONAL_STANDARD = 'dhl_ecommerce_parcel_international_standard'
    DHL_ECOMMERCE_BPM_EXPEDITED = 'dhl_ecommerce_bpm_expedited'
    DHL_ECOMMERCE_PARCEL_INTERNATIONAL_EXPEDITED = 'dhl_ecommerce_parcel_international_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_PRIORITY = 'dhl_ecommerce_globalmail_packet_priority'
    DHL_ECOMMERCE_EASY_RETURN_LIGHT = 'dhl_ecommerce_easy_return_light'
    DHL_ECOMMERCE_PARCEL_PLUS_EXPEDITED = 'dhl_ecommerce_parcel_plus_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_STANDARD = 'dhl_ecommerce_globalmail_business_standard'
    DHL_ECOMMERCE_GROUND = 'dhl_ecommerce_ground'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_STANDARD = 'dhl_ecommerce_globalmail_packet_standard'

class ServiceLevelDHLExpressEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dhl_express_domestic_express_doc | Domestic Express Doc|
    | dhl_express_economy_select_doc | Economy Select Doc|
    | dhl_express_worldwide_nondoc | Express Worldwide Nondoc|
    | dhl_express_worldwide_doc | Express Worldwide Doc|
    | dhl_express_worldwide | Worldwide|
    | dhl_express_worldwide_eu_doc | Express Worldwide EU Doc|
    | dhl_express_break_bulk_express_doc | Break Bulk Express Doc|
    | dhl_express_express_9_00_nondoc | Express 9:00 NonDoc|
    | dhl_express_economy_select_nondoc | Economy Select NonDoc|
    | dhl_express_break_bulk_economy_doc | Break Bulk Economy Doc|
    | dhl_express_express_9_00_doc | Express 9:00 Doc|
    | dhl_express_express_10_30_doc | Express 10:30 Doc|
    | dhl_express_express_10_30_nondoc | Express 10:30 NonDoc|
    | dhl_express_express_12_00_doc | Express 12:00 Doc|
    | dhl_express_europack_nondoc | Europack NonDoc|
    | dhl_express_express_envelope_doc | Express Envelope Doc|
    | dhl_express_express_12_00_nondoc | Express 12:00 NonDoc|
    | dhl_express_express_12_doc | Domestic Express 12:00|
    | dhl_express_worldwide_b2c_doc | Express Worldwide (B2C) Doc|
    | dhl_express_worldwide_b2c_nondoc | Express Worldwide (B2C) NonDoc|
    | dhl_express_medical_express | Medical Express|
    | dhl_express_express_easy_nondoc | Express Easy NonDoc|
    """
    DHL_EXPRESS_DOMESTIC_EXPRESS_DOC = 'dhl_express_domestic_express_doc'
    DHL_EXPRESS_ECONOMY_SELECT_DOC = 'dhl_express_economy_select_doc'
    DHL_EXPRESS_WORLDWIDE_NONDOC = 'dhl_express_worldwide_nondoc'
    DHL_EXPRESS_WORLDWIDE_DOC = 'dhl_express_worldwide_doc'
    DHL_EXPRESS_WORLDWIDE = 'dhl_express_worldwide'
    DHL_EXPRESS_WORLDWIDE_EU_DOC = 'dhl_express_worldwide_eu_doc'
    DHL_EXPRESS_BREAK_BULK_EXPRESS_DOC = 'dhl_express_break_bulk_express_doc'
    DHL_EXPRESS_EXPRESS_9_00_NONDOC = 'dhl_express_express_9_00_nondoc'
    DHL_EXPRESS_ECONOMY_SELECT_NONDOC = 'dhl_express_economy_select_nondoc'
    DHL_EXPRESS_BREAK_BULK_ECONOMY_DOC = 'dhl_express_break_bulk_economy_doc'
    DHL_EXPRESS_EXPRESS_9_00_DOC = 'dhl_express_express_9_00_doc'
    DHL_EXPRESS_EXPRESS_10_30_DOC = 'dhl_express_express_10_30_doc'
    DHL_EXPRESS_EXPRESS_10_30_NONDOC = 'dhl_express_express_10_30_nondoc'
    DHL_EXPRESS_EXPRESS_12_00_DOC = 'dhl_express_express_12_00_doc'
    DHL_EXPRESS_EUROPACK_NONDOC = 'dhl_express_europack_nondoc'
    DHL_EXPRESS_EXPRESS_ENVELOPE_DOC = 'dhl_express_express_envelope_doc'
    DHL_EXPRESS_EXPRESS_12_00_NONDOC = 'dhl_express_express_12_00_nondoc'
    DHL_EXPRESS_EXPRESS_12_DOC = 'dhl_express_express_12_doc'
    DHL_EXPRESS_WORLDWIDE_B2C_DOC = 'dhl_express_worldwide_b2c_doc'
    DHL_EXPRESS_WORLDWIDE_B2C_NONDOC = 'dhl_express_worldwide_b2c_nondoc'
    DHL_EXPRESS_MEDICAL_EXPRESS = 'dhl_express_medical_express'
    DHL_EXPRESS_EXPRESS_EASY_NONDOC = 'dhl_express_express_easy_nondoc'

class ServiceLevelPurolatorEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | purolator_ground | Ground|
    | purolator_ground9_am | Ground 9am|
    | purolator_ground1030_am | Ground 10:30am|
    | purolator_ground_distribution | Ground Distribution|
    | purolator_ground_evening | Ground Evening|
    | purolator_ground_us | Ground US|
    | purolator_express | Express|
    | purolator_express9_am | Express 9am|
    | purolator_express1030_am | Express 10am|
    | purolator_express_evening | Express Evening|
    | purolator_express_us | Express US|
    | purolator_express_us9_am | Express US 9am|
    | purolator_express_us1030_am | Express US 10:30am|
    | purolator_express_us1200 | Express US 12pm|
    | purolator_express_international | Express International|
    | purolator_express_international9_am | Express International 9am|
    | purolator_express_international1030_am | Express International 10:30am|
    | purolator_express_international1200 | Express International 12pm|
    """
    PUROLATOR_GROUND = 'purolator_ground'
    PUROLATOR_GROUND9_AM = 'purolator_ground9_am'
    PUROLATOR_GROUND1030_AM = 'purolator_ground1030_am'
    PUROLATOR_GROUND_DISTRIBUTION = 'purolator_ground_distribution'
    PUROLATOR_GROUND_EVENING = 'purolator_ground_evening'
    PUROLATOR_GROUND_US = 'purolator_ground_us'
    PUROLATOR_EXPRESS = 'purolator_express'
    PUROLATOR_EXPRESS9_AM = 'purolator_express9_am'
    PUROLATOR_EXPRESS1030_AM = 'purolator_express1030_am'
    PUROLATOR_EXPRESS_EVENING = 'purolator_express_evening'
    PUROLATOR_EXPRESS_US = 'purolator_express_us'
    PUROLATOR_EXPRESS_US9_AM = 'purolator_express_us9_am'
    PUROLATOR_EXPRESS_US1030_AM = 'purolator_express_us1030_am'
    PUROLATOR_EXPRESS_US1200 = 'purolator_express_us1200'
    PUROLATOR_EXPRESS_INTERNATIONAL = 'purolator_express_international'
    PUROLATOR_EXPRESS_INTERNATIONAL9_AM = 'purolator_express_international9_am'
    PUROLATOR_EXPRESS_INTERNATIONAL1030_AM = 'purolator_express_international1030_am'
    PUROLATOR_EXPRESS_INTERNATIONAL1200 = 'purolator_express_international1200'

class ServiceLevelColissimoEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | colissimo_home | Domicile|
    | colissimo_pick_up_point | Point Retrait|
    | colissimo_return_mainland_france | Retour France|
    """
    COLISSIMO_HOME = 'colissimo_home'
    COLISSIMO_PICK_UP_POINT = 'colissimo_pick_up_point'
    COLISSIMO_RETURN_MAINLAND_FRANCE = 'colissimo_return_mainland_france'

class ServiceLevelCorreosEspanaEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | correos_standard_home| Paquete Estándar|
    | correos_premium_home | Paquete Premium|
    """
    CORREOS_STANDARD_HOME = 'correos_standard_home'
    CORREOS_PREMIUM_HOME = 'correos_premium_home'

class ServiceLevelCouriersPleaseEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | couriersplease_domestic_priority_auth_to_leave | Domestic Priority - Authority To Leave/POPPoints|
    | couriersplease_domestic_priority_sign_required | Domestic Priority - Signature Required|
    | couriersplease_gold_domestic_auth_to_leave | Gold Domestic - Authority To Leave/POPPoints|
    | couriersplease_gold_domestic_sign_required | Gold Domestic - Signature Required|
    | couriersplease_off_peak_auth_to_leave | Off Peak - Authority To Leave/POPPoints|
    | couriersplease_off_peak_sign_required | Off Peak - Signature Required|
    | couriersplease_parcel_auth_to_leave | Parcel - Authority To Leave|
    | couriersplease_parcel_sign_required | Parcel - Signature Required|
    | couriersplease_road_express | Road Express|
    | couriersplease_satchel_auth_to_leave | Satchel - Authority To Leave|
    | couriersplease_satchel_sign_required | Satchel - Signature Required|
    """
    COURIERSPLEASE_DOMESTIC_PRIORITY_AUTH_TO_LEAVE = 'couriersplease_domestic_priority_auth_to_leave'
    COURIERSPLEASE_DOMESTIC_PRIORITY_SIGN_REQUIRED = 'couriersplease_domestic_priority_sign_required'
    COURIERSPLEASE_GOLD_DOMESTIC_AUTH_TO_LEAVE = 'couriersplease_gold_domestic_auth_to_leave'
    COURIERSPLEASE_GOLD_DOMESTIC_SIGN_REQUIRED = 'couriersplease_gold_domestic_sign_required'
    COURIERSPLEASE_OFF_PEAK_AUTH_TO_LEAVE = 'couriersplease_off_peak_auth_to_leave'
    COURIERSPLEASE_OFF_PEAK_SIGN_REQUIRED = 'couriersplease_off_peak_sign_required'
    COURIERSPLEASE_PARCEL_AUTH_TO_LEAVE = 'couriersplease_parcel_auth_to_leave'
    COURIERSPLEASE_PARCEL_SIGN_REQUIRED = 'couriersplease_parcel_sign_required'
    COURIERSPLEASE_ROAD_EXPRESS = 'couriersplease_road_express'
    COURIERSPLEASE_SATCHEL_AUTH_TO_LEAVE = 'couriersplease_satchel_auth_to_leave'
    COURIERSPLEASE_SATCHEL_SIGN_REQUIRED = 'couriersplease_satchel_sign_required'

class ServiceLevelChronopostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | chronopost_13 | Chrono 13|
    | chronopost_10 | Chrono 10|
    | chronopost_18| Chrono 18|
    | chronopost_relais_fr | Chrono Point Relais|
    | chronopost_classic | Chrono Classic International|
    | chronopost_express | Chrono Express International|
    """
    CHRONOPOST_13 = 'chronopost_13'
    CHRONOPOST_10 = 'chronopost_10'
    CHRONOPOST_18 = 'chronopost_18'
    CHRONOPOST_RELAIS_FR = 'chronopost_relais_fr'
    CHRONOPOST_CLASSIC = 'chronopost_classic'
    CHRONOPOST_EXPRESS = 'chronopost_express'

class ServiceLevelCDLEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | cdl_next_day | Next Day|
    """
    CDL_NEXT_DAY = 'cdl_next_day'

class ServiceLevelCanadaPostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | canada_post_regular_parcel | Regular Parcel|
    | canada_post_expedited_parcel | Expedited Parcel|
    | canada_post_priority | Priority|
    | canada_post_xpresspost | Xpresspost|
    | canada_post_xpresspost_international | Xpresspost International|
    | canada_post_xpresspost_usa | Xpresspost USA|
    | canada_post_expedited_parcel_usa | Expedited Parcel USA|
    | canada_post_tracked_packet_usa | Tracked Packet USA|
    | canada_post_small_packet_usa_air | Small Packet USA Air|
    | canada_post_tracked_packet_international | Tracked Packet International|
    | canada_post_small_packet_international_air | Small Package International Air|
    """
    CANADA_POST_REGULAR_PARCEL = 'canada_post_regular_parcel'
    CANADA_POST_EXPEDITED_PARCEL = 'canada_post_expedited_parcel'
    CANADA_POST_PRIORITY = 'canada_post_priority'
    CANADA_POST_XPRESSPOST = 'canada_post_xpresspost'
    CANADA_POST_XPRESSPOST_INTERNATIONAL = 'canada_post_xpresspost_international'
    CANADA_POST_XPRESSPOST_USA = 'canada_post_xpresspost_usa'
    CANADA_POST_EXPEDITED_PARCEL_USA = 'canada_post_expedited_parcel_usa'
    CANADA_POST_TRACKED_PACKET_USA = 'canada_post_tracked_packet_usa'
    CANADA_POST_SMALL_PACKET_USA_AIR = 'canada_post_small_packet_usa_air'
    CANADA_POST_TRACKED_PACKET_INTERNATIONAL = 'canada_post_tracked_packet_international'
    CANADA_POST_SMALL_PACKET_INTERNATIONAL_AIR = 'canada_post_small_packet_international_air'

class ServiceLevelBetterTrucksEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | better_trucks_same_day | Same Day|
    | better_trucks_next_day | Next Day|
    """
    BETTER_TRUCKS_SAME_DAY = 'better_trucks_same_day'
    BETTER_TRUCKS_NEXT_DAY = 'better_trucks_next_day'

class ServiceLevelAPGEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | epacket | ePacket|
    | epacket_plus | ePacket Plus|
    | eparcel_premium | eParcel premium|
    | apg_eparcel_expedited | eParcel Expedited|
    """
    EPACKET = 'epacket'
    EPACKET_PLUS = 'epacket_plus'
    EPARCEL_PREMIUM = 'eparcel_premium'
    APG_EPARCEL_EXPEDITED = 'apg_eparcel_expedited'

class ServiceLevelAxleHireEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | axlehire_same_day | Same Day|
    | axlehire_next_day | Next Day|
    """
    AXLEHIRE_SAME_DAY = 'axlehire_same_day'
    AXLEHIRE_NEXT_DAY = 'axlehire_next_day'

class ServiceLevelAustraliaPostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | australia_post_express_post | Express Post|
    | australia_post_parcel_post | Parcel Post|
    | australia_post_pack_and_track_international | Pack and Track International|
    | australia_post_international_airmail | International Airmail|
    | australia_post_express_post_international | Express Post International|
    | australia_post_express_courier_international | Express Courier International|
    | australia_post_international_express | International Express|
    | australia_post_international_standard | International Standard|
    | australia_post_international_economy | International Economy|
    | australia_post_parcel_post_return | Parcel Post Return|
    """
    AUSTRALIA_POST_EXPRESS_POST = 'australia_post_express_post'
    AUSTRALIA_POST_PARCEL_POST = 'australia_post_parcel_post'
    AUSTRALIA_POST_PACK_AND_TRACK_INTERNATIONAL = 'australia_post_pack_and_track_international'
    AUSTRALIA_POST_INTERNATIONAL_AIRMAIL = 'australia_post_international_airmail'
    AUSTRALIA_POST_EXPRESS_POST_INTERNATIONAL = 'australia_post_express_post_international'
    AUSTRALIA_POST_EXPRESS_COURIER_INTERNATIONAL = 'australia_post_express_courier_international'
    AUSTRALIA_POST_INTERNATIONAL_EXPRESS = 'australia_post_international_express'
    AUSTRALIA_POST_INTERNATIONAL_STANDARD = 'australia_post_international_standard'
    AUSTRALIA_POST_INTERNATIONAL_ECONOMY = 'australia_post_international_economy'
    AUSTRALIA_POST_PARCEL_POST_RETURN = 'australia_post_parcel_post_return'

class ServiceLevelAsendiaEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | asendia_us_priority_tracked | Asendia USA Priority Tracked|
    | asendia_us_international_express | Asendia USA International Express|
    | asendia_us_international_priority_airmail | Asendia USA International Priority Airmail|
    | asendia_us_international_surface_airlift | Asendia USA International Surface Air Lift|
    | asendia_us_priority_mail_international | Asendia USA Priority Mail International|
    | asendia_us_priority_mail_express_international | Asendia USA Priority Mail Express International|
    | asendia_us_epacket | Asendia USA International ePacket|
    | asendia_us_other | Asendia USA Other Services (custom)|
    """
    ASENDIA_US_PRIORITY_TRACKED = 'asendia_us_priority_tracked'
    ASENDIA_US_INTERNATIONAL_EXPRESS = 'asendia_us_international_express'
    ASENDIA_US_INTERNATIONAL_PRIORITY_AIRMAIL = 'asendia_us_international_priority_airmail'
    ASENDIA_US_INTERNATIONAL_SURFACE_AIRLIFT = 'asendia_us_international_surface_airlift'
    ASENDIA_US_PRIORITY_MAIL_INTERNATIONAL = 'asendia_us_priority_mail_international'
    ASENDIA_US_PRIORITY_MAIL_EXPRESS_INTERNATIONAL = 'asendia_us_priority_mail_express_international'
    ASENDIA_US_EPACKET = 'asendia_us_epacket'
    ASENDIA_US_OTHER = 'asendia_us_other'

class ServiceLevelAPCPostalEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | apc_postal_parcelconnect_expedited | parcelConnect Expedited|
    | apc_postal_parcelconnect_priority | parcelConnect Priority|
    | apc_postal_parcelconnect_priority_delcon | parcelConnect Priority Delcon|
    | apc_postal_parcelconnect_priority_pqw | parcelConnect Priority PQW|
    | apc_postal_parcelconnect_book_service | parcelConnect Book Service|
    | apc_postal_parcelconnect_standard | parcelConnect Standard|
    | apc_postal_parcelconnect_epmi | parcelConnect ePMI|
    | apc_postal_parcelconnect_epacket | parcelConnect ePacket|
    | apc_postal_parcelconnect_epmei | parcelConnect ePMEI|
    """
    APC_POSTAL_PARCELCONNECT_EXPEDITED = 'apc_postal_parcelconnect_expedited'
    APC_POSTAL_PARCELCONNECT_PRIORITY = 'apc_postal_parcelconnect_priority'
    APC_POSTAL_PARCELCONNECT_PRIORITY_DELCON = 'apc_postal_parcelconnect_priority_delcon'
    APC_POSTAL_PARCELCONNECT_PRIORITY_PQW = 'apc_postal_parcelconnect_priority_pqw'
    APC_POSTAL_PARCELCONNECT_BOOK_SERVICE = 'apc_postal_parcelconnect_book_service'
    APC_POSTAL_PARCELCONNECT_STANDARD = 'apc_postal_parcelconnect_standard'
    APC_POSTAL_PARCELCONNECT_EPMI = 'apc_postal_parcelconnect_epmi'
    APC_POSTAL_PARCELCONNECT_EPACKET = 'apc_postal_parcelconnect_epacket'
    APC_POSTAL_PARCELCONNECT_EPMEI = 'apc_postal_parcelconnect_epmei'

class ServiceLevelAirterraEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | airterra_ground | GroundXC|
    | airterra_postal | FastPost|
    """
    AIRTERRA_GROUND = 'airterra_ground'
    AIRTERRA_POSTAL = 'airterra_postal'

class ServiceLevelUPSEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | ups_standard | Standard℠|
    | ups_ground | Ground|
    | ups_saver | Saver®|
    | ups_3_day_select | 3 Day Select®|
    | ups_second_day_air | 2nd Day Air®|
    | ups_second_day_air_am | 2nd Day Air® A.M.|
    | ups_next_day_air | Next Day Air®|
    | ups_next_day_air_saver | Next Day Air Saver®|
    | ups_next_day_air_early_am | Next Day Air® Early|
    | ups_mail_innovations_bpm_flat | Mail Innovations BPM Flat |
    | ups_mail_innovations_bpm_parcel | Mail Innovations BPM Parcel |
    | ups_mail_innovations_irregular | Mail Innovations Irregular |
    | ups_mail_innovations_media_mail | Mail Innovations Media Mail |
    | ups_mail_innovations_parcel | Mail Innovations Parcel |
    | ups_mail_innovations_standard_flat | Mail Innovations Standard Flat |
    | ups_surepost | Surepost|
    | ups_surepost_bound_printed_matter | SurePost® Bound Printed Matter|
    | ups_surepost_lightweight | Surepost Lightweight|
    | ups_surepost_media | SurePost® Media|
    | ups_express | Express®|
    | ups_express_1200 | Express 12:00|
    | ups_express_plus | Express Plus®|
    | ups_expedited | Expedited®|
    | ups_express_early | Express® Early|
    | ups_access_point_economy | Access Point™ Economy|
    """
    UPS_STANDARD = 'ups_standard'
    UPS_GROUND = 'ups_ground'
    UPS_SAVER = 'ups_saver'
    UPS_3_DAY_SELECT = 'ups_3_day_select'
    UPS_SECOND_DAY_AIR = 'ups_second_day_air'
    UPS_SECOND_DAY_AIR_AM = 'ups_second_day_air_am'
    UPS_NEXT_DAY_AIR = 'ups_next_day_air'
    UPS_NEXT_DAY_AIR_SAVER = 'ups_next_day_air_saver'
    UPS_NEXT_DAY_AIR_EARLY_AM = 'ups_next_day_air_early_am'
    UPS_MAIL_INNOVATIONS_BPM_FLAT = 'ups_mail_innovations_bpm_flat'
    UPS_MAIL_INNOVATIONS_BPM_PARCEL = 'ups_mail_innovations_bpm_parcel'
    UPS_MAIL_INNOVATIONS_IRREGULAR = 'ups_mail_innovations_irregular'
    UPS_MAIL_INNOVATIONS_MEDIA_MAIL = 'ups_mail_innovations_media_mail'
    UPS_MAIL_INNOVATIONS_PARCEL = 'ups_mail_innovations_parcel'
    UPS_MAIL_INNOVATIONS_STANDARD_FLAT = 'ups_mail_innovations_standard_flat'
    UPS_SUREPOST = 'ups_surepost'
    UPS_SUREPOST_BOUND_PRINTED_MATTER = 'ups_surepost_bound_printed_matter'
    UPS_SUREPOST_LIGHTWEIGHT = 'ups_surepost_lightweight'
    UPS_SUREPOST_MEDIA = 'ups_surepost_media'
    UPS_EXPRESS = 'ups_express'
    UPS_EXPRESS_1200 = 'ups_express_1200'
    UPS_EXPRESS_PLUS = 'ups_express_plus'
    UPS_EXPEDITED = 'ups_expedited'
    UPS_EXPRESS_EARLY = 'ups_express_early'
    UPS_ACCESS_POINT_ECONOMY = 'ups_access_point_economy'

class ServiceLevelFedExEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | fedex_ground | FedEx Ground®|
    | fedex_home_delivery | FedEx Home Delivery®|
    | fedex_ground_economy | FedEx Ground® Economy|
    | fedex_2_day | FedEx 2Day®|
    | fedex_2_day_am | FedEx 2Day® A.M.|
    | fedex_express_saver | FedEx Express Saver®|
    | fedex_standard_overnight | FedEx Standard Overnight®|
    | fedex_priority_overnight | FedEx Priority Overnight®|
    | fedex_first_overnight | FedEx First Overnight®|
    | fedex_freight_priority | FedEx Freight® Priority|
    | fedex_next_day_freight | FedEx Next Day Freight|
    | fedex_freight_economy | FedEx Freight® Economy|
    | fedex_first_freight | FedEx First Freight|
    | fedex_international_economy | FedEx International Economy®|
    | fedex_international_priority | FedEx International Priority®|
    | fedex_international_first | FedEx International First®|
    | fedex_europe_first_international_priority | FedEx International First®|
    | fedex_international_connect_plus | FedEx International Connect Plus|
    | international_economy_freight | FedEx International Economy® Freight|
    | international_priority_freight | FedEx International Priority® Freight|
    """
    FEDEX_GROUND = 'fedex_ground'
    FEDEX_HOME_DELIVERY = 'fedex_home_delivery'
    FEDEX_SMART_POST = 'fedex_smart_post'
    FEDEX_GROUND_ECONOMY = 'fedex_ground_economy'
    FEDEX_2_DAY = 'fedex_2_day'
    FEDEX_2_DAY_AM = 'fedex_2_day_am'
    FEDEX_EXPRESS_SAVER = 'fedex_express_saver'
    FEDEX_STANDARD_OVERNIGHT = 'fedex_standard_overnight'
    FEDEX_PRIORITY_OVERNIGHT = 'fedex_priority_overnight'
    FEDEX_FIRST_OVERNIGHT = 'fedex_first_overnight'
    FEDEX_FREIGHT_PRIORITY = 'fedex_freight_priority'
    FEDEX_NEXT_DAY_FREIGHT = 'fedex_next_day_freight'
    FEDEX_FREIGHT_ECONOMY = 'fedex_freight_economy'
    FEDEX_FIRST_FREIGHT = 'fedex_first_freight'
    FEDEX_INTERNATIONAL_ECONOMY = 'fedex_international_economy'
    FEDEX_INTERNATIONAL_PRIORITY = 'fedex_international_priority'
    FEDEX_INTERNATIONAL_FIRST = 'fedex_international_first'
    FEDEX_EUROPE_FIRST_INTERNATIONAL_PRIORITY = 'fedex_europe_first_international_priority'
    FEDEX_INTERNATIONAL_CONNECT_PLUS = 'fedex_international_connect_plus'
    INTERNATIONAL_ECONOMY_FREIGHT = 'international_economy_freight'
    INTERNATIONAL_PRIORITY_FREIGHT = 'international_priority_freight'

class ServiceLevelUSPSEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | usps_priority | Priority Mail|
    | usps_priority_express | Priority Mail Express|
    | usps_media_mail | Media Mail, only for existing Shippo customers with grandfathered Media Mail option.|
    | usps_priority_mail_international | Priority Mail International|
    | usps_priority_mail_express_international | Priority Mail Express International|
    | usps_first_class_package_international_service | First Class Package International|
    | usps_ground_advantage | Ground Advantage |
    """
    USPS_PRIORITY = 'usps_priority'
    USPS_PRIORITY_EXPRESS = 'usps_priority_express'
    USPS_MEDIA_MAIL = 'usps_media_mail'
    USPS_PRIORITY_MAIL_INTERNATIONAL = 'usps_priority_mail_international'
    USPS_PRIORITY_MAIL_EXPRESS_INTERNATIONAL = 'usps_priority_mail_express_international'
    USPS_FIRST_CLASS_PACKAGE_INTERNATIONAL_SERVICE = 'usps_first_class_package_international_service'
    USPS_GROUND_ADVANTAGE = 'usps_ground_advantage'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from .labelfiletypeenum import LabelFileTypeEnum
from .objectstateenum import ObjectStateEnum
from .trackingstatusenum import TrackingStatusEnum
from .transactionstatusenum import TransactionStatusEnum
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from shippo import utils
from typing import List, Optional


@dataclasses.dataclass
class TransactionMessages:
    pass

class ResponseType(str, Enum):
    STANDARD = 'standard'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Transaction:
    commercial_invoice_url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('commercial_invoice_url'), 'exclude': lambda f: f is None }})
    r"""A URL pointing to the commercial invoice as a 8.5x11 inch PDF file.
    A value will only be returned if the Transactions has been processed successfully and if the shipment is international.
    """
    eta: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('eta'), 'exclude': lambda f: f is None }})
    r"""The estimated time of arrival according to the carrier."""
    label_file_type: Optional[LabelFileTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('label_file_type'), 'exclude': lambda f: f is None }})
    r"""Print format of the <a href=\\"https://docs.goshippo.com/docs/shipments/shippinglabelsizes/\\">label</a>. If empty, will use the default format set from
    <a href=\"https://apps.goshippo.com/settings/labels\">the Shippo dashboard.</a>
    """
    label_url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('label_url'), 'exclude': lambda f: f is None }})
    r"""A URL pointing directly to the label in the format you've set in your settings.
    A value will only be returned if the Transactions has been processed successfully.
    """
    messages: Optional[List[TransactionMessages]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('messages'), 'exclude': lambda f: f is None }})
    r"""An array containing elements of the following schema:<br>
    `code` (string): an identifier for the corresponding message (not always available)<br>
    `message` (string): a publishable message containing further information.
    """
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    r"""A string of up to 100 characters that can be filled with any additional information you want to
    attach to the object.
    """
    object_created: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_created'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    r"""Date and time of Transaction creation."""
    object_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_id'), 'exclude': lambda f: f is None }})
    r"""Unique identifier of the given Transaction object."""
    object_owner: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_owner'), 'exclude': lambda f: f is None }})
    r"""Username of the user who created the Transaction object."""
    object_state: Optional[ObjectStateEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_state'), 'exclude': lambda f: f is None }})
    r"""Indicates the validity of the enclosing object"""
    object_updated: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_updated'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    r"""Date and time of last Transaction update."""
    qr_code_url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('qr_code_url'), 'exclude': lambda f: f is None }})
    r"""A URL pointing directly to the QR code in PNG format.
    A value will only be returned if requested using qr_code_requested flag and the carrier provides such an option.
    """
    status: Optional[TransactionStatusEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status'), 'exclude': lambda f: f is None }})
    r"""Indicates the status of the Transaction."""
    test: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('test'), 'exclude': lambda f: f is None }})
    r"""Indicates whether the object has been created in test mode."""
    tracking_number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tracking_number'), 'exclude': lambda f: f is None }})
    r"""The carrier-specific tracking number that can be used to track the Shipment.
    A value will only be returned if the Rate is for a trackable Shipment and if the Transactions has been processed successfully.
    """
    tracking_status: Optional[TrackingStatusEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tracking_status'), 'exclude': lambda f: f is None }})
    r"""Indicates the high level status of the shipment."""
    tracking_url_provider: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tracking_url_provider'), 'exclude': lambda f: f is None }})
    r"""A link to track this item on the carrier-provided tracking website.
    A value will only be returned if tracking is available and the carrier provides such a service.
    """
    rate: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('rate'), 'exclude': lambda f: f is None }})
    r"""ID of the Rate object for which a Label has to be obtained.
    Please note that only rates that are not older than 7 days can be purchased in order to ensure up-to-date pricing.
    """
    response_type: Optional[ResponseType] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('responseType'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from .customsdeclarationb13afilingoptionenum import CustomsDeclarationB13AFilingOptionEnum
from .customsdeclarationcontentstypeenum import CustomsDeclarationContentsTypeEnum
from .customsdeclarationeelpfcenum import CustomsDeclarationEelPfcEnum
from .customsdeclarationincotermenum import CustomsDeclarationIncotermEnum
from .customsdeclarationnondeliveryoptionenum import CustomsDeclarationNonDeliveryOptionEnum
from .customsexporteridentification import CustomsExporterIdentification
from .customsinvoicedcharges import CustomsInvoicedCharges
from .objectstateenum import ObjectStateEnum
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from shippo import utils
from typing import Any, List, Optional


@dataclasses.dataclass
class CustomsDeclarationAddressImporter:
    r"""Object ID of the Importer address."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CustomsDeclaration:
    certify: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('certify') }})
    r"""Expresses that the certify_signer has provided all information of this customs declaration truthfully."""
    certify_signer: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('certify_signer') }})
    r"""Name of the person who created the customs declaration and is responsible for the validity of all
    information provided.
    """
    contents_type: CustomsDeclarationContentsTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('contents_type') }})
    r"""Type of goods of the shipment."""
    non_delivery_option: CustomsDeclarationNonDeliveryOptionEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('non_delivery_option') }})
    r"""Indicates how the carrier should proceed in case the shipment can't be delivered."""
    items: List[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('items') }})
    r"""Distinct Parcel content items as Customs Items object_ids."""
    aes_itn: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('aes_itn'), 'exclude': lambda f: f is None }})
    r"""**required if eel_pfc is `AES_ITN`**<br>
    AES / ITN reference of the shipment.
    """
    b13a_filing_option: Optional[CustomsDeclarationB13AFilingOptionEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('b13a_filing_option'), 'exclude': lambda f: f is None }})
    r"""B13A Option details are obtained by filing a B13A Canada Export Declaration via the Canadian Export Reporting System (CERS).
    <a href=\"https://www.cbsa-asfc.gc.ca/services/export/guide-eng.html\" target=\"_blank\" rel=\"noopener noreferrer\"> More information on reporting commercial exports from Canada. </a>
    """
    b13a_number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('b13a_number'), 'exclude': lambda f: f is None }})
    r"""**must be provided if and only if b13a_filing_option is provided**<br>
    Represents:<br> the Proof of Report (POR) Number when b13a_filing_option is `FILED_ELECTRONICALLY`;<br> 
    the Summary ID Number when b13a_filing_option is `SUMMARY_REPORTING`;<br> 
    or the Exemption Number when b13a_filing_option is `NOT_REQUIRED`.
    """
    certificate: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('certificate'), 'exclude': lambda f: f is None }})
    r"""Certificate reference of the shipment."""
    commercial_invoice: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('commercial_invoice'), 'exclude': lambda f: f is None }})
    contents_explanation: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('contents_explanation'), 'exclude': lambda f: f is None }})
    r"""**required if contents_type is `OTHER`**<br>
    Explanation of the type of goods of the shipment.
    """
    disclaimer: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('disclaimer'), 'exclude': lambda f: f is None }})
    r"""Disclaimer for the shipment and customs information that have been provided."""
    eel_pfc: Optional[CustomsDeclarationEelPfcEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('eel_pfc'), 'exclude': lambda f: f is None }})
    r"""EEL / PFC type of the shipment. For most shipments from the US to CA, `NOEEI_30_36` is applicable; for most
    other shipments from the US, `NOEEI_30_37_a` is applicable.
    """
    exporter_reference: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('exporter_reference'), 'exclude': lambda f: f is None }})
    r"""Exporter reference of an export shipment."""
    importer_reference: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('importer_reference'), 'exclude': lambda f: f is None }})
    r"""Importer reference of an import shipment."""
    incoterm: Optional[CustomsDeclarationIncotermEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('incoterm'), 'exclude': lambda f: f is None }})
    r"""The incoterm reference of the shipment. FCA is available for DHL Express and FedEx only.
    eDAP is available for DPD UK only. DAP is available for DHL Express and DPD UK.
    If expecting DAP for other carriers, please use DDU.
    """
    is_vat_collected: Optional[Any] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('is_vat_collected'), 'exclude': lambda f: f is None }})
    r"""Indicates whether the shipment's destination VAT has been collected. May be required for some destinations."""
    invoice: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invoice'), 'exclude': lambda f: f is None }})
    r"""Invoice reference of the shipment."""
    license: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('license'), 'exclude': lambda f: f is None }})
    r"""License reference of the shipment."""
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    r"""A string of up to 100 characters that can be filled with any additional information you
    want to attach to the object.
    """
    notes: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('notes'), 'exclude': lambda f: f is None }})
    r"""Additional notes to be included in the customs declaration."""
    address_importer: Optional[CustomsDeclarationAddressImporter] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address_importer'), 'exclude': lambda f: f is None }})
    r"""Object ID of the Importer address."""
    exporter_identification: Optional[CustomsExporterIdentification] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('exporter_identification'), 'exclude': lambda f: f is None }})
    r"""Additional exporter identification that may be required to ship in certain countries"""
    invoiced_charges: Optional[CustomsInvoicedCharges] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invoiced_charges'), 'exclude': lambda f: f is None }})
    r"""Additional invoiced charges to be shown on the Customs Declaration Commercial Invoice."""
    object_created: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_created'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    r"""Date and time of object creation."""
    object_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_id'), 'exclude': lambda f: f is None }})
    r"""Unique identifier of the given object."""
    object_owner: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_owner'), 'exclude': lambda f: f is None }})
    r"""Username of the user who created the object."""
    object_state: Optional[ObjectStateEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_state'), 'exclude': lambda f: f is None }})
    r"""Indicates the validity of the enclosing object"""
    object_updated: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_updated'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    r"""Date and time of last object update."""
    test: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('test'), 'exclude': lambda f: f is None }})
    r"""Indicates whether the object has been created in test mode."""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from shippo import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShippoAccount:
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})
    first_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('first_name') }})
    last_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('last_name') }})
    company_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('company_name') }})
    object_created: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_created'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    object_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_id'), 'exclude': lambda f: f is None }})
    object_updated: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('object_updated'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class DistanceUnitEnum(str, Enum):
    r"""The measure unit used for length, width and height."""
    CM = 'cm'
    IN = 'in'
    FT = 'ft'
    M = 'm'
    MM = 'mm'
    YD = 'yd'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .addresscompletecreaterequest import AddressCompleteCreateRequest
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from shippo import utils
from typing import Optional

class BuildingLocationType(str, Enum):
    r"""Where your parcels will be available for pickup. \\"Security Deck\\" and \\"Shipping Dock\\" are only
    supported for DHL Express.
    """
    BACK_DOOR = 'Back Door'
    RING_BELL = 'Ring Bell'
    SECURITY_DECK = 'Security Deck'
    SHIPPING_DOCK = 'Shipping Dock'
    FRONT_DOOR = 'Front Door'
    KNOCK_ON_DOOR = 'Knock on Door'
    IN_AT_MAILBOX = 'In/At Mailbox'
    MAIL_ROOM = 'Mail Room'
    OFFICE = 'Office'
    OTHER = 'Other'
    RECEPTION = 'Reception'
    SIDE_DOOR = 'Side Door'

class BuildingType(str, Enum):
    r"""The type of building where the pickup is located."""
    APARTMENT = 'apartment'
    BUILDING = 'building'
    DEPARTMENT = 'department'
    FLOOR = 'floor'
    ROOM = 'room'
    SUITE = 'suite'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Location:
    r"""Location where the parcel(s) will be picked up."""
    address: AddressCompleteCreateRequest = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address') }})
    r"""The pickup address, which includes your name, company name, street address, city, state, zip code,
    country, phone number, and email address (strings). Special characters should not be included in 
    any address element, especially name, company, and email.
    """
    building_location_type: BuildingLocationType = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('building_location_type') }})
    r"""Where your parcels will be available for pickup. \\"Security Deck\\" and \\"Shipping Dock\\" are only
    supported for DHL Express.
    """
    building_type: Optional[BuildingType] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('building_type'), 'exclude': lambda f: f is None }})
    r"""The type of building where the pickup is located."""
    instructions: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('instructions'), 'exclude': lambda f: f is None }})
    r"""Pickup instructions for the courier. This is a mandatory field if the building_location_type is \\"Other\\"."""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from .addresses import Addresses
from .batches import Batches
from .carrier_accounts import CarrierAccounts
from .carrier_parcel_templates import CarrierParcelTemplates
from .customs_declarations import CustomsDeclarations
from .customs_items import CustomsItems
from .manifests import Manifests
from .orders import Orders
from .parcels import Parcels
from .pickups import Pickups
from .rates import Rates
from .rates_at_checkout import RatesAtCheckout
from .refunds import Refunds
from .sdkconfiguration import SDKConfiguration
from .service_groups import ServiceGroups
from .shipments import Shipments
from .shippo_accounts import ShippoAccounts
from .tracking_status import TrackingStatus
from .transactions import Transactions
from .user_parcel_templates import UserParcelTemplates
from .utils.retries import RetryConfig
from shippo import utils
from shippo._hooks import SDKHooks
from shippo.models import components, internal
from typing import Callable, Dict, Optional, Union

class Shippo:
    r"""Shippo external API.: Use this API to integrate with the Shippo service"""
    addresses: Addresses
    r"""Addresses are the locations a parcel is being shipped **from** and **to**. They represent company and residential places. Among other things, you can use address objects to create shipments, calculate shipping rates, and purchase shipping labels.
    <SchemaDefinition schemaRef=\"#/components/schemas/Address\"/>
    """
    batches: Batches
    r"""A batch is a technique for creating multiple labels at once. Use the  batch object to create and purchase many shipments in two API calls. After creating the batch, retrieve the batch to verify that all shipments are valid. You can add and remove shipments after you have created the batch. When all shipments are valid you can purchase the batch and retrieve all the shipping labels.
    <SchemaDefinition schemaRef=\"#/components/schemas/Batch\"/>

    # Batch Shipment
    The batch shipment object is a wrapper around a shipment object, which include shipment-specific information 
    for batch processing.

    Note: batch shipments can only be created on the batch endpoint, either when creating a batch object or by through 
    the `/batches/{BATCH_OBJECT_ID}/add_shipments` endpoint
    <SchemaDefinition schemaRef=\"#/components/schemas/BatchShipment\"/>
    """
    carrier_accounts: CarrierAccounts
    r"""Carriers are the companies who deliver your package. Shippo uses Carrier account objects as credentials to retrieve shipping rates and purchase labels from shipping Carriers.

    <SchemaDefinition schemaRef=\"#/components/schemas/CarrierAccount\"/>
    """
    customs_declarations: CustomsDeclarations
    r"""Customs declarations are relevant information, including one or multiple customs items, you need to provide for
    customs clearance for your international shipments.
    <SchemaDefinition schemaRef=\"#/components/schemas/CustomsDeclaration\"/>
    """
    customs_items: CustomsItems
    r"""Customs declarations are relevant information, including one or multiple customs items, you need to provide for customs clearance for your international shipments.
    <SchemaDefinition schemaRef=\"#/components/schemas/CustomsItem\"/>
    """
    rates_at_checkout: RatesAtCheckout
    r"""Rates at checkout is a tool for merchants to display up-to-date shipping estimates based on what's in their customers cart and where they’re shipping to.
    Merchants set up curated shipping options for customers in the checkout flow based on data in the shopping cart. The request must include the **to** address and item information. Optional fields are the **from** address and package information. If the optional fields are not included, the service will use the default address and/or package configured for rates at checkout. The response is a list of shipping options based on the Service Group configuration.
    (see <a href=\"#tag/Service-Groups\">Service Group configuration</a> for details).
    <SchemaDefinition schemaRef=\"#/components/schemas/LiveRate\"/>


    # Default Parcel Template
    Assign one of your user parcel templates to be the default used when generating Live Rates. This template will be used by default when generating Live Rates, unless you explicitly provide a parcel in the Live Rates request.
    <SchemaDefinition schemaRef=\"#/components/schemas/UserParcelTemplate\"/>
    """
    manifests: Manifests
    r"""A manifest is a single-page document with a barcode that carriers can scan to accept all packages into transit without the need to scan each item individually.
    They are close-outs of shipping labels of a certain day. Some carriers require manifests to  process the shipments.

    <SchemaDefinition schemaRef=\"#/components/schemas/Manifest\"/>

    # Manifest Errors
    The following codes and messages are the possible errors that may occur when creating Manifests.
    <SchemaDefinition schemaRef=\"#/components/schemas/ManifestErrors\"/>
    """
    orders: Orders
    r"""An order is a request from a customer to purchase goods from a merchant.
    Use the orders object to load orders from your system to the Shippo dashboard.
    You can use the orders object to create, retrieve, list, and manage orders programmatically. 
    You can also retrieve shipping rates, purchase labels, and track shipments for each order.
    <SchemaDefinition schemaRef=\"#/components/schemas/Order\"/>

    # Line Item
    <p style=\"text-align: center; background-color: #F2F3F4;\">
      </br>Line Items, and their corresponding abstract Products and Variants, might be exposed as a separate resource 
      in the future. Currently it's a nested object within the order resource.</br></br>
    </p>
     A line item is an individual object in an order. For example, if your order contains a t-shirt, shorts, and a jacket, each item is represented by a line item.
    <SchemaDefinition schemaRef=\"#/components/schemas/LineItem\"/>
    """
    carrier_parcel_templates: CarrierParcelTemplates
    r"""A carrier parcel template represents a package used for shipping that has preset dimensions defined by a carrier. Some examples of a carrier parcel template include USPS Flat Rate Box and Fedex Small Pak. When using a carrier parcel template, the rates returned may be limited to the carrier that provides the box. You can create user parcel templates using a carrier parcel template. Shippo takes the dimensions of the carrier parcel template but you must configure the weight.

    <SchemaDefinition schemaRef=\"#/components/schemas/CarrierParcelTemplate\"/>
    """
    parcels: Parcels
    r"""A parcel is an item you are shipping. The parcel object includes details about its physical make-up of the parcel. It includes dimensions and weight that Shippo uses to calculate rates.
    <SchemaDefinition schemaRef=\"#/components/schemas/Parcel\"/>

    # Parcel Extras
    The following values are supported for the `extra` field of the parcel object.
    <SchemaDefinition schemaRef=\"#/components/schemas/ParcelExtra\"/>
    """
    pickups: Pickups
    r"""A pickup is when you schedule a carrier to collect a package for delivery.
    Use Shippo’s pickups endpoint to schedule pickups with USPS and DHL Express for eligible shipments that you have already created.
    <SchemaDefinition schemaRef=\"#/components/schemas/Pickup\"/>
    """
    rates: Rates
    r"""A rate is the cost to ship a parcel from a carrier. The rate object details the service level including the cost and transit time.
    <SchemaDefinition schemaRef=\"#/components/schemas/Rate\"/>
    """
    refunds: Refunds
    r"""Refunds are reimbursements for successfully created but unused shipping labels or other charges.
    <SchemaDefinition schemaRef=\"#/components/schemas/Refund\"/>
    """
    service_groups: ServiceGroups
    r"""A service group is a set of service levels grouped together.
    Rates at checkout uses services groups to present available shipping options to customers in their shopping basket.
    <SchemaDefinition schemaRef=\"#/components/schemas/ServiceGroup\"/>
    """
    shipments: Shipments
    r"""A shipment is the act of transporting goods. A shipment object contains **to** and **from** addresses, and the parcel details that you are shipping. You can use the shipment object to retrieve shipping rates and purchase a shipping label.
    <SchemaDefinition schemaRef=\"#/components/schemas/Shipment\"/>

    # Shipment Extras
    The following values are supported for the `extra` field of the shipment object.
    <SchemaDefinition schemaRef=\"#/components/schemas/ShipmentExtra\"/>
    """
    tracking_status: TrackingStatus
    r"""<p style=\\"text-align: center; background-color: #F2F3F4;\\"></br>
    If you purchased your shipping label through Shippo, you can also get all the tracking details of your Shipment 
    from the <a href=\"#tag/Transactions\">Transaction</a> object.
    </br></br></p>
    A tracking status of a package is an indication of current location of a package in the supply chain. For example,  sorting, warehousing, or out for delivery. Use the tracking status object to track the location of your shipments.

    When using your <a href=\"https://docs.goshippo.com/docs/guides_general/authentication/\">Test</a> token for tracking, you need to use Shippo's 
    predefined tokens for testing different tracking statuses. You can find more information in our 
    <a href=\"https://docs.goshippo.com/docs/tracking/tracking/\">Tracking tutorial</a> on how to do this, and what the 
    payloads look like.      
    <SchemaDefinition schemaRef=\"#/components/schemas/Track\"/>
    """
    transactions: Transactions
    r"""A transaction is the purchase of a shipping label from a shipping provider for a specific service. You can print purchased labels and used them to ship a parcel with a carrier, such as USPS or FedEx.
    <SchemaDefinition schemaRef=\"#/components/schemas/Transaction\"/>
    """
    user_parcel_templates: UserParcelTemplates
    r"""A user parcel template represents a package used for shipping that has preset dimensions and attributes defined
    by you. They are useful for capturing attributes of parcel-types you frequently use for shipping, allowing 
    them to be defined once and then used for many shipments. These parcel templates can also be used for live rates.

    User parcel templates can also be created using a carrier parcel template, where the dimensions will be copied from 
    the carrier presets, but the weight can be configured by you.
    <SchemaDefinition schemaRef=\"#/components/schemas/UserParcelTemplate\"/>
    """
    shippo_accounts: ShippoAccounts
    r"""Shippo Accounts are used by Shippo Platform Accounts to create and manage Managed Shippo Accounts.
    Managed Shippo Accounts are headless accounts that represent your customers. They are opaque to your end customers, meaning customers do not need to create their own Shippo login or have a billing relationship with Shippo. 
    They can be used by marketplaces, e-commerce platforms, and third-party logistics providers who want to offer, seamless, built-in shipping functionality to their customers. 
    <SchemaDefinition schemaRef=\"#/components/schemas/ShippoAccount\"/>
    """

    sdk_configuration: SDKConfiguration

    def __init__(self,
                 api_key_header: Union[str, Callable[[], str]],
                 shippo_api_version: str = None,
                 server_idx: Optional[int] = None,
                 server_url: Optional[str] = None,
                 url_params: Optional[Dict[str, str]] = None,
                 client: Optional[requests_http.Session] = None,
                 retry_config: Optional[RetryConfig] = None
                 ) -> None:
        """Instantiates the SDK configuring it with the provided parameters.

        :param api_key_header: The api_key_header required for authentication
        :type api_key_header: Union[str, Callable[[], str]]
        :param shippo_api_version: Configures the shippo_api_version parameter for all supported operations
        :type shippo_api_version: str
        :param server_idx: The index of the server to use for all operations
        :type server_idx: int
        :param server_url: The server URL to use for all operations
        :type server_url: str
        :param url_params: Parameters to optionally template the server URL with
        :type url_params: Dict[str, str]
        :param client: The requests.Session HTTP client to use for all operations
        :type client: requests_http.Session
        :param retry_config: The utils.RetryConfig to use globally
        :type retry_config: RetryConfig
        """
        if client is None:
            client = requests_http.Session()

        if callable(api_key_header):
            def security():
                return components.Security(api_key_header = api_key_header())
        else:
            security = components.Security(api_key_header = api_key_header)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)
    
        _globals = internal.Globals(
            shippo_api_version=shippo_api_version,
        )

        self.sdk_configuration = SDKConfiguration(
            client,
            _globals,
            security,
            server_url,
            server_idx,
            retry_config=retry_config
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(current_server_url, self.sdk_configuration.client)
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__['_hooks'] = hooks

        self._init_sdks()


    def _init_sdks(self):
        self.addresses = Addresses(self.sdk_configuration)
        self.batches = Batches(self.sdk_configuration)
        self.carrier_accounts = CarrierAccounts(self.sdk_configuration)
        self.customs_declarations = CustomsDeclarations(self.sdk_configuration)
        self.customs_items = CustomsItems(self.sdk_configuration)
        self.rates_at_checkout = RatesAtCheckout(self.sdk_configuration)
        self.manifests = Manifests(self.sdk_configuration)
        self.orders = Orders(self.sdk_configuration)
        self.carrier_parcel_templates = CarrierParcelTemplates(self.sdk_configuration)
        self.parcels = Parcels(self.sdk_configuration)
        self.pickups = Pickups(self.sdk_configuration)
        self.rates = Rates(self.sdk_configuration)
        self.refunds = Refunds(self.sdk_configuration)
        self.service_groups = ServiceGroups(self.sdk_configuration)
        self.shipments = Shipments(self.sdk_configuration)
        self.tracking_status = TrackingStatus(self.sdk_configuration)
        self.transactions = Transactions(self.sdk_configuration)
        self.user_parcel_templates = UserParcelTemplates(self.sdk_configuration)
        self.shippo_accounts = ShippoAccounts(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .initiateoauth2signin import *
from .sdkerror import *

__all__ = ["InitiateOauth2SigninCarrierAccountsResponseBody","InitiateOauth2SigninCarrierAccountsResponseResponseBody","InitiateOauth2SigninResponseBody","SDKError"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class CustomsDeclarationIncotermEnum(str, Enum):
    r"""The incoterm reference of the shipment. FCA is available for DHL Express and FedEx only.
    eDAP is available for DPD UK only. DAP is available for DHL Express and DPD UK.
    If expecting DAP for other carriers, please use DDU.
    """
    DDP = 'DDP'
    DDU = 'DDU'
    FCA = 'FCA'
    DAP = 'DAP'
    E_DAP = 'eDAP'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .batchshipmentbase import BatchShipmentBase
from .labelfiletypeenum import LabelFileTypeEnum
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import List, Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class BatchCreateRequest:
    default_carrier_account: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('default_carrier_account') }})
    r"""ID of the Carrier Account object to use as the default for all shipments in this Batch.
    The carrier account can be changed on a per-shipment basis by changing the carrier_account in the 
    corresponding BatchShipment object.
    """
    default_servicelevel_token: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('default_servicelevel_token') }})
    r"""Token of the service level to use as the default for all shipments in this Batch.
    The servicelevel can be changed on a per-shipment basis by changing the servicelevel_token in the 
    corresponding BatchShipment object. <a href=\"#tag/Service-Levels\">Servicelevel tokens can be found here.</a>
    """
    batch_shipments: List[BatchShipmentBase] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('batch_shipments') }})
    r"""Array of BatchShipment objects. The response keeps the same order as in the request array."""
    label_filetype: Optional[LabelFileTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('label_filetype'), 'exclude': lambda f: f is None }})
    r"""Print format of the <a href=\\"https://docs.goshippo.com/docs/shipments/shippinglabelsizes/\\">label</a>. If empty, will use the default format set from
    <a href=\"https://apps.goshippo.com/settings/labels\">the Shippo dashboard.</a>
    """
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    r"""A string of up to 100 characters that can be filled with any additional information you want to attach to the object."""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .shipmentcreaterequest import ShipmentCreateRequest
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from shippo import utils
from typing import Optional

class LabelFileType(str, Enum):
    PNG = 'PNG'
    PNG_2_3X7_5 = 'PNG_2.3x7.5'
    PDF = 'PDF'
    PDF_2_3X7_5 = 'PDF_2.3x7.5'
    PDF_4X6 = 'PDF_4x6'
    PDF_4X8 = 'PDF_4x8'
    PDF_A4 = 'PDF_A4'
    PDF_A6 = 'PDF_A6'
    ZPLII = 'ZPLII'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InstantTransactionCreateRequest:
    carrier_account: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('carrier_account') }})
    servicelevel_token: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('servicelevel_token') }})
    shipment: ShipmentCreateRequest = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('shipment') }})
    label_file_type: Optional[LabelFileType] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('label_file_type'), 'exclude': lambda f: f is None }})
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    

